@@ -359,11 +359,9 @@ class BottleClient:
         return result
 
     @_ensure_connected
-    def get_model(self, model_name: Dict, nodes: List = None) -> Union[dict, Any]:
+    def get_model(self, model_name: str, nodes: List = None) -> Union[dict, Any]:
         """Returns model with name *model_name*.
 
-        data : {primitive_name : name}
-
         Model name is unique, so it should not matter that we query all nodes, only
         one model will be found.
         """
@@ -411,24 +409,19 @@ class BottleClient:
         result = {}
         for node in nodes:
             try:
-                response = requests.post(
-                    self.url,
-                    verify=self.secure,
-                    json={
-                        "method": "getVector",
-                        "params": {"api_key": self.api_key, "primitive_id": node['id'], "data": vector_name},
-                        "jsonrpc": "2.0",
-                        "id": 1,
-                    },
-                ).json()['result']
+                response = requests.get(
+                    f"{self.url}{node['id']}/vector", headers=self.headers, verify=self.secure, json={'data': vector_name}
+                ).json()
                 if 'error' in response or response['status'] == 'failed':
                     if len(nodes) == 1 and self.summarize_for_single_node:
                         raise BottleQueryError(response)
                 if len(nodes) == 1 and self.summarize_for_single_node:
-                    return {vector_name: response}
-                result[node['name']] = {vector_name: response}
+                    return response['message']
+                else:
+                    result[node['name']] = response['message']
             except Exception as exception:
                 raise BottleQueryError(str(exception)) from None
+
         return result
 
     @_ensure_connected
